ws_storage
==========
.. image:: https://travis-ci.org/chuck1/ws_storage.svg?branch=master
    :target: https://travis-ci.org/chuck1/ws_storage
.. image:: https://codecov.io/gh/chuck1/ws_storage/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/chuck1/ws_storage
.. image:: https://readthedocs.org/projects/ws_storage/badge/?version=latest
   :target: http://ws_storage.readthedocs.io/
   :alt: Documentation Status
.. image:: https://img.shields.io/pypi/v/ws_storage.svg
   :target: https://pypi.python.org/pypi/ws_storage
.. image:: https://img.shields.io/pypi/pyversions/ws_storage.svg
   :target: https://pypi.python.org/pypi/ws_storage

A simple binary storage module and command line program created for use with ws_web_aiohttp_.

.. _ws_web_aiohttp github.com/chuck1/ws_web_aiohttp

Install
-------

::

    pip3 install ws_storage

Test
----

::

    git clone git@github.com:chuck1/ws_storage
    cd ws_storage
    pip install -e .
    pytest


